@@ -53,9 +53,9 @@ def refresh():
 
 	#clear and rebuild listbox_item
 	listbox_item.delete(0, END)
-	for i in g.inv:
-		if i != -1 and (g.item[i][1] == 11 or g.item[i][1] == 12):
-			listbox_item.insert(END, g.item[i][0])
+	for i in g.item.inv:
+		if i != -1 and (g.item.item[i].type == 11 or g.item.item[i].type == 12):
+			listbox_item.insert(END, g.item.item[i].name)
 
 	#clear and rebuild listbox_skill
 	listbox_skill.delete(0, END)
@@ -181,16 +181,16 @@ def useitem():
 
 
 	#find the item[] index and item type
-	item_value = g.finditem(item_name)
-	item_type = g.item[item_value][1]
+	item_value = g.item.finditem(item_name)
+	item_type = g.item.item[item_value].type
 
 	#if item is healing
 	if item_type == 11:
 		#heal the player, delete the item
-		g.hp=g.hp + g.item[item_value][2]
+		g.hp=g.hp + g.item.item[item_value].quality
 		main.print_message("You are healed for " +
-					str(g.item[item_value][2]) + " health.")
-		g.drop_inv_item(g.find_inv_item(item_value))
+					str(g.item.item[item_value].quality) + " health.")
+		g.item.drop_inv_item(g.item.find_inv_item(item_value))
 		if g.hp >= g.maxhp: g.hp = g.maxhp
 		attack_player()
 
@@ -198,8 +198,8 @@ def useitem():
 	if item_type == 12:
 		#if monster is still alive
 		if g.cur_mon_hp > 0:
-			damage = int(g.item[item_value][2])
-			g.drop_inv_item(g.find_inv_item(item_value))
+			damage = int(g.item.item[item_value].quality)
+			g.item.drop_inv_item(g.item.find_inv_item(item_value))
 			if damage > 0:
 				main.print_message("The " + monster.monsters[mon_index].name +
 					" is hit for " + str(damage) + " damage.")
