@@ -34,6 +34,7 @@ window.title("Map Editor")
 
 cur_tile = ""
 cur_tile_num = 0
+cur_mode = "replace"
 border = "rock.png"
 background = "grass.png"
 map_name = "map.txt"
@@ -43,6 +44,9 @@ tilegrid = 0 #whether or not to display the map grid
 cur_map = "" #this will normally be a g.map class.
 global dirnames
 dirnames = []
+#all possible items so we can make unique variables for each one
+global item_list
+item_list = {"blank": 4}
 
 #create a new map. Set mapsize_* first.
 def create_map():
@@ -136,9 +140,14 @@ def move_right(event=None):
 	refresh_map()
 
 def map_callback(event):
-	if(cur_tile != ""):
+	if(cur_tile != "" or cur_mode == "remove"):
 		set_tile((event.x / g.tilesize)+portal_x, (event.y / g.tilesize)+portal_y, cur_tile)
 
+#set mode to add, replace, or remove
+def set_mode(mode):
+    global cur_mode
+    cur_mode = mode
+
 #set all interior tiles to background tile
 def set_bkg(bkg):
 	for y in range(mapsize_y-2):
@@ -198,6 +207,12 @@ def set_tile(x, y, name):
 	tile_prefix = name.split("/", 1)[0]
 	if tile_prefix == "items":
 		add_item(x, y, name)
+	elif cur_mode == "add":
+	    	cur_map.field[y][x].onload.append("addpix " + name);
+	elif cur_mode == "remove":
+	   	cur_map.field[y][x].onload = []
+		cur_map.field[y][x].onload.append("pix " + background)
+                cur_map.field[y][x].onload.append("walk 1")
 	else:
 		temp_name = name
 		for line_num in range(len(cur_map.field[y][x].onload)):
@@ -214,13 +229,14 @@ def add_item(x, y, name):
 	item = name.split("/", 1)[1]
 	item = item[0:len(item)-4]
 	item_name = re.sub("_", " ", item)
-	cur_map.field[y][x].onload.append("if var " + item + "_added | end | addpix " + name)
-	cur_map.field[y][x].onload.append("set " + item + "_added = 1")
+	var_name = item + "_found" + str(item_list[name])
+	item_list[name] += 1
+	cur_map.field[y][x].onload.append("if var " + var_name + " | end | addpix " + name)
 	global amount
 	amount = "AMOUNT"
 	set_item_amount()
-	cur_map.field[y][x].actions.append("if var got_" + item + "| end | find \""  + item_name + "\" " + amount)
-	cur_map.field[y][x].actions.append("if got \"" + item_name + "\" | set got_" + item + " = 1 | end")
+	cur_map.field[y][x].actions.append("if var " + var_name + "| end | pass")
+	cur_map.field[y][x].actions.append("if find \""  + item_name + "\" " + amount + " | set " + var_name + " = 1 | end")
 	cur_map.field[y][x].actions.append("delpix " + name)
 
 def set_item_amount():
@@ -679,6 +695,13 @@ def make_menus():
 	map_options = Menu(mbutton, bg=bgcolour)
 	mbutton.config(menu=map_options)
 
+	#mapmode submenu
+	mapmode_menu = Menu(map_options, bg=bgcolour)
+	map_options.add_cascade(label='Map Mode', menu=mapmode_menu)
+	mapmode_menu.add_command(label='Replace Tile (default)', command=(lambda x="replace":set_mode(x)))
+	mapmode_menu.add_command(label='Add Tile (transparency)', command=(lambda x="add":set_mode(x)))
+	mapmode_menu.add_command(label='Reset Tile (clear to background)', command=(lambda x="remove":set_mode(x)))
+
 	#mapsize submenu
 	mapsize_menu = Menu(map_options, bg=bgcolour)
 	map_options.add_cascade(label='Map Size',menu=mapsize_menu)
@@ -749,6 +772,7 @@ def sel_mod(selected_mod):
 	display_tiles("default")
 
 from os import listdir
+
 array_mods = listdir("../modules/")
 i = 0
 while i < len(array_mods):
@@ -795,4 +819,14 @@ else:
 		dirnames.append(modname)
 	window.withdraw()
 
+# put all items in a list
+item_dir = listdir("../modules/" + array_mods[0] + "/images/tiles/items")
+j=0
+while j<len(item_dir):
+	if item_dir[j] != "CVS":
+		name = "items/" + item_dir[j]
+		item_list[name] = 0
+	j += 1
+
+
 window.master.wait_window(window)
