@@ -8,6 +8,7 @@
 from Tkinter import *
 import main
 import g
+import item
 
 
 #type of the store: Weapon store is 1, general store is 2,
@@ -35,10 +36,10 @@ def refresh_inv():
 	listbox_inv_array[0:len(listbox_inv_array)] = []
 
 	#fill in listbox
-	for i in g.inv:
+	for i in item.inv:
 		if i != -1:
 			listbox_inv_array.append(i)
-			listbox_inv.insert(END, g.item[i][0])
+			listbox_inv.insert(END, item.item[i].name)
 
 	#set gold and skillpoints
 	curr_gold.set("Gold: " + str(g.gold))
@@ -68,17 +69,17 @@ def show_inv_details(event=0, called_from="mouse"):
 			return 0
 	else: cur_item = listbox_inv.get(0)
 	#convert from name to ID.
-	item_loc = g.finditem(cur_item)
+	item_loc = item.finditem(cur_item)
 	if (item_loc == -1): return 0
 	#fill in the actual info
 
-	item_name.set(g.item[item_loc][0])
-	item_cost.set("Cost: " + str(g.item[item_loc][3]) + " AU")
-	item_power.set("Power: " + str(g.item[item_loc][2]))
+	item_name.set(item.item[item_loc].name)
+	item_cost.set("Cost: " + str(item.item[item_loc].price) + " AU")
+	item_power.set("Power: " + str(item.item[item_loc].quality))
 
 	canvas_desc.delete("all")
 	canvas_desc.create_text(1, 5, anchor=NW,
-			text=g.item[item_loc][4], width=142)
+			text=item.item[item_loc].description, width=142)
 
 
 	#disable/enable buttons as needed.
@@ -154,19 +155,19 @@ def sell_item():
 	#find what item is selected
 	try: item_num = map(int, listbox_inv.curselection())
 	except ValueError: pass
-	try: item_to_delete = g.find_inv_item(listbox_inv_array[item_num[0]])
+	try: item_to_delete = item.find_inv_item(listbox_inv_array[item_num[0]])
 	except IndexError: return 0
 
 	#give the player money
 	#note that all stores have a 5 year, money-back guarantee,
 	#and accept returns from other stores as well.
 	#This means there is no need to doublecheck intent. ;)
-	main.print_message("You sell your " + g.item[g.inv[item_to_delete]][0]
+	main.print_message("You sell your " + item.item[item.inv[item_to_delete]].name
 		+ ".")
-	g.gold = int(g.gold) + g.item[g.inv[item_to_delete]][3]
+	g.gold = int(g.gold) + item.item[item.inv[item_to_delete]].price
 
 	#remove the item
-	g.drop_inv_item(item_num[0])
+	item.drop_inv_item(item_num[0])
 
 	refresh_inv()
 	listbox_inv.selection_set(0)
